pytilities.test.overloading.overloaded

Package pytilities :: Package test :: Package overloading :: Module overloaded |
[hide private]
[frames] | no frames]

# Module overloaded

source code

Classes | [hide private]
| Storage Something with an x and y
| A Some class to test with
| MethodTestCase Test overloading of a method
| FunctionTestCase Test overloading of a function

Functions | [hide private]
__init_xy(x, y) | source code
__init_storage(storage) | source code

Variables | [hide private]
| __package__ = ``'``pytilities.test.overloading``'``